#
# spec file for package appstream-glib
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2014 Dominique Leuenberger, Amsterdam, The Netherlands
# Copyright (c) 2024 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           appstream-glib
Version:        0.8.3
Release:        1.2
Summary:        AppStream Abstraction Library
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
URL:            https://people.freedesktop.org/~hughsient/appstream-glib/
Source0:        %{name}-%{version}.tar.xz
Source1:        openSUSE-appstream-process
# PATCH-FIX-OPENSUSE
Patch1:         0001-Move-from-app-info-to-swcatalog-locations.patch
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  gcab >= 0.6
BuildRequires:  gobject-introspection-devel
BuildRequires:  gperf
BuildRequires:  gtk-doc
BuildRequires:  meson
BuildRequires:  pkgconfig
# We still need some part to build the man pages
BuildRequires:  xsltproc
BuildRequires:  pkgconfig(gdk-pixbuf-2.0) >= 2.31.5
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gio-unix-2.0) >= 2.45.8
BuildRequires:  pkgconfig(glib-2.0) >= 2.45.8
BuildRequires:  pkgconfig(gmodule-2.0) >= 2.45.8
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(json-glib-1.0) >= 1.1.2
BuildRequires:  pkgconfig(libarchive)
BuildRequires:  pkgconfig(libcurl) >= 7.56.0
BuildRequires:  pkgconfig(libgcab-1.0)
BuildRequires:  pkgconfig(rpm)
BuildRequires:  pkgconfig(uuid)
BuildRequires:  pkgconfig(yaml-0.1)
Requires:       gcab
# Required in order to be able to convert .svg icons
Requires:       gdk-pixbuf-loader-rsvg
Requires:       pngquant >= 2.8
# Due to patch1 only swcatalog will be populated.
# Older libs would not find any info anymore.
Conflicts:      libappstream4 < 0.15.2
Provides:       asglib(swcatalog)

%description
This library provides GObjects and helper methods to read and write
AppStream metadata. It also provides a DOM implementation to edit
nodes and convert to and from the standardized XML representation.

This library allows to:

* Read and write compressed AppStream XML files
* Add and search for applications in an application store
* Get screenshot image data and release announcements
* Easily retrieve the best application data for the current locale
* Efficiently interface with more heavy-weight parsers like expat

%package -n libappstream-glib8
Summary:        AppStream Abstraction Library
License:        LGPL-2.1-or-later

%description -n libappstream-glib8
This library provides GObjects and helper methods to read and write
AppStream metadata. It also provides a DOM implementation to edit
nodes and convert to and from the standardized XML representation.

%package -n typelib-1_0-AppStreamGlib-1_0
Summary:        Introspection bindings for the AppStream abstraction library
License:        LGPL-2.1-or-later

%description -n typelib-1_0-AppStreamGlib-1_0
This library provides GObjects and helper methods to read and write
AppStream metadata. It also provides a DOM implementation to edit
nodes and convert to and from the standardized XML representation.

%package devel
Summary:        Development files for the AppStream abstraction library
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Requires:       %{name} = %{version}
Requires:       libappstream-glib8 = %{version}
Requires:       typelib-1_0-AppStreamGlib-1_0 = %{version}
# appdata-tools was consumed into appstream-glib and is no longer maintained upstream
Obsoletes:      appdata-tools < 0.1.9
Provides:       appdata-tools = 0.1.9
# Also obsolete the -lang package; or we end up with strange conflicts
Obsoletes:      appdata-tools-lang < 0.1.9

%description devel
This library provides GObjects and helper methods to read and write
AppStream metadata. It also provides a DOM implementation to edit
nodes and convert to and from the standardized XML representation.

This library allows to:

* Read and write compressed AppStream XML files
* Add and search for applications in an application store
* Get screenshot image data and release announcements
* Easily retrieve the best application data for the current locale
* Efficiently interface with more heavy-weight parsers like expat

%package -n openSUSE-appstream-process
Summary:        Appstream processor employed by kiwi
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Requires:       appstream-glib >= %{version}
Requires:       openSUSE-appdata-extra

%description -n openSUSE-appstream-process
A wrapper around appstream-builder, called by kiwi in order to produce AppStream metadata
for the repositories to be published

%lang_package

%prep
%autosetup -p1

%build
%meson \
	-Ddep11=true \
	-Dbuilder=true \
	-Drpm=true \
	-Dalpm=false \
	-Dfonts=false \
	-Dman=true \
	-Dgtk-doc=true \
	-Dintrospection=true \
	%{nil}
%meson_build

%install
%meson_install
# We don't care for 'installed tests'; that's used by GNOME Smoke Testing.
rm %{buildroot}%{_datadir}/installed-tests/appstream-glib/*.test

# install the appstream process script to be used by kiwi
install -d -m 0755 %{_buildroot}%{_bindir}
install -m 0755 -D %{SOURCE1} %{buildroot}%{_bindir}/$(basename %{SOURCE1})

%find_lang %{name}

%check
if %meson_test; then
  echo CHECKS passed
  exit 0
else
  echo CHECKS failed... dumping log file
  find -name testlog.txt -exec cat {} +
  exit 0
fi

%ldconfig_scriptlets -n libappstream-glib8

%files
%doc AUTHORS NEWS
%{_bindir}/appstream-builder
%{_bindir}/appstream-compose
%{_bindir}/appstream-util
%{_datadir}/bash-completion/completions/appstream-builder
%{_datadir}/bash-completion/completions/appstream-util
%{_libdir}/asb-plugins-5/
%{_mandir}/man1/appstream-builder.1%{?ext_man}
%{_mandir}/man1/appstream-compose.1%{?ext_man}
%{_mandir}/man1/appstream-util.1%{?ext_man}

%files -n libappstream-glib8
%license COPYING
%{_libdir}/libappstream-glib.so.*

%files -n typelib-1_0-AppStreamGlib-1_0
%{_libdir}/girepository-1.0/AppStreamGlib-1.0.typelib

%files devel
%doc MAINTAINERS README.md
%{_datadir}/aclocal/appdata-xml.m4
%{_datadir}/aclocal/appstream-xml.m4
%dir %{_datadir}/gettext/its
%{_datadir}/gettext/its/appdata.*
%{_datadir}/gir-1.0/AppStreamGlib-1.0.gir
%{_datadir}/gtk-doc/html/appstream-glib/
%{_includedir}/libappstream-glib/
%{_libdir}/pkgconfig/appstream-glib.pc
%{_libdir}/libappstream-glib.so

%files -n openSUSE-appstream-process
%{_bindir}/openSUSE-appstream-process

%files lang -f %{name}.lang

%changelog
* Sun Aug 25 2024 Andreas Stieger <andreas.stieger@gmx.de>
- Update to version 0.8.3:
  * Drop support for libstemmer
  * Do not veto the extension if the parent cannot be found
  * Support RFC9512 registration for application/yaml
  * Stop trying to convert Fedora licenses into SPDX
  * asb-plugin-font: Add glob match for .ttc files
  * Update gl.po
  * Update Simplified Chinese translation
  * Make the appdata filename check match the plugin globs
  * Remove Check for X-KDE-StartupNotify
  * Update Russian translation
  * Include screenshot size in "too large" errors
  * Include screenshot height in "too small" error
* Fri Feb  9 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Add asglib(swcatalog) provides: allow other packages to declare
  that they need swcatalog support.
* Thu Feb  1 2024 Fabian Vogt <fvogt@suse.com>
- Add patch for interoperability with newer AppStream spec (boo#1218427):
  * 0001-Move-from-app-info-to-swcatalog-locations.patch
* Thu Nov 17 2022 Dominique Leuenberger <dimstar@opensuse.org>
- openSUSE-appstream-process: drop --enable-hidpi parameter:
  - -enable-hidpi now does nothing and will be removed in future
  versions.
* Mon Nov 14 2022 dimstar@opensuse.org
- Update to version 0.8.2:
  + asb-plugin-appdata: Never add default icons to firmware, IMs or
    codecs.
  + Tell CURL to follow http redirect for validate.
  + Updated translations.
* Thu Sep  1 2022 bjorn.lie@gmail.com
- Update to version 0.8.1:
  * Initialize proxy resolver in appstream-validate
  * Improve handling of <em> and <code> tags
  * trivial: Turn is_{em,code}_text fields into bitfields
  * Properly initialize AsNodeToXmlHelper
  * Correct typos in as-app.c
- Changes from version 0.8.0:
  * Use GProxyResolver to auto-detect the correct proxy
  * Port from libsoup to libcurl
  * Remove the --enable-hidpi option completely
  * Updated translations.
- Replace pkgconfig(libsoup-2.4) with pkgconfig(libcurl)
  BuildRequires following upstreams port.
- Use ldconfig_scriptlets macro for post(un) handling.
* Thu Jun 23 2022 dimstar@opensuse.org
- Update to version 0.7.18+37:
  * Update fa.po
  * trivial: Fix a tiny memory leak when mirroring screenshots
  * trivial: Be explicit when ignoring return error values
  * trivial: Fix a tiny memory leak on failure
  * Add vcs-browser and contribute URL type
  * update to spdx 3.16
* Sun Mar 13 2022 bjorn.lie@gmail.com
- Update to version 0.7.18+31:
  * Fix extracting relative symlinks (boo#1196459)
* Wed Feb 16 2022 dimstar@opensuse.org
- Update to version 0.7.18+30:
  * libappstream-builder: Fix file paths in icon tarball
* Tue Feb 15 2022 dimstar@opensuse.org
- Update to version 0.7.18+29:
  * Updated translations.
- Improve _service file to handle to drop +0 in versions for when
  we are exactly on a tag.
* Tue Feb  8 2022 bjorn.lie@gmail.com
- Update to version 0.7.18+28:
  * as-app: Also unwrap description in metainfo files
  * Fix validation of translated captions when LANG is not C
  * Revert "Don't emit legacy component type values"
  * Don't emit legacy component type values
  * its: Sync with appstream
  * Consider AppStream version as a string
  * meson: Check --version-script linker option before using.
  * Update current newest version in AsStore
  * Support em/code tags Some appstream-data packages add <em> and
    </em> or <code> and </code> to the files. Not all package
    manager can handle that. An example would be pamac from Manjaro
  * Update asb-self-test to match current behavior
  * Add validation for duplicate license xml elements
  * builder: make directories as 0755 && umask
  * Do not show a critical warning on <suggests><id/></suggests>
  * libappstream-builder: Fix paths for cached icons
  * as-util: Fix Markdown underlining in appdata-to-news
  * Replace links http://standards.freedesktop.org/... by https in
    README.md
  * Replace a link http://www.freedesktop.org/wiki/... by https in
    README.md
  * as-app: Parse launchables from DEP-11
  * as-app: Parse custom tags from DEP-11
  * as-content-rating: Align the OARS/CSM mappings of sex-*
  * Updated translations.
- Switch to current git head, upstream is not making releases.
- Drop 0001-as-app-Also-unwrap-description-in-metainfo-files.patch:
  Fixed upstream.
* Tue Feb  8 2022 Fabian Vogt <fvogt@suse.com>
- Add patch to fix descriptions in .metainfo.xml files
  (boo#1192243, gh#hughsie/appstream-glib#381):
  * 0001-as-app-Also-unwrap-description-in-metainfo-files.patch
* Sun Sep 13 2020 elimat@opensuse.org
- Update to version 0.7.18:
  * Don't ignore localized strings that are the same as original
  * Croatian translation 2nd attempt (#373)
  * Test launchable tags in validation
  * Add missing dependency to the readme
  * as-app: Don't initialize mutex twice
  * as-content-rating: Expand translator comments to link to OARS website
  * as-content-rating: Lower the OARS/CSM mapping of sex-homosexuality/intense
  * po: Import gs-content-rating.c translations from gnome-software
  * po: Update po files
  * as-content-rating: Add content rating system APIs from gnome-software
  * Allow timestamp in the future in validate-relax
  * Fix crash with invalid children of <ul/>
  * as-app: Properly initialize unique_id_mutex
  * The AppData files now go to /usr/share/metainfo
  * util: Complete new validate-version command
  * util: Add "validate-version" command
  * trivial: Actually use the correct NEWS contents
  * trivial: post release version bump
- Drop patch as-glib-PR359.patch (fixed upstream)
- Run spec-cleaner
  * Remove rpm groups
* Wed Apr 22 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Add as-glib-PR359.patch: Fix crash with invalid children of <ul>.
* Wed Apr 15 2020 dimstar@opensuse.org
- Update to version 0.7.17:
  * Support versioning on clang/macOS
  * Use ".so" suffix for the plugins on macOS
  * Use internal uuid library in macOS
  * docs: Fix examples of AsNodeToXmlFlags using an invalid flag.
  * Bump minimum glib2 dependency.
  * Update Galician translations
  * as-app: properly initialize unique_id_mutex
  * Use _fullpath() instead of GetFullPathNameA().
  * Fix Win32 headers.
  * Support ${id}/${locale}.qm in addition to ${id}_${locale}.qm
  * as-app: add "icon-theme" as recognised component type
  * as-content-rating: Make default values match OARS semantics
* Thu Dec 19 2019 dimstar@opensuse.org
- Update to version 0.7.16:
  * Allow parsing desktop files using as_app_parse_data()
  * Update list of allowed metadata licences
  * Log expected and actual screenshot dimensions when failing
  * docs: remove SQLite dependency
  * Offset future checks by UTC+14
  * Do not preserve restrictive permissions when installing AppStream files
  * Support loading YAML from as_store_from_bytes
  * Do not allow forward or backwards slashes in <id> values
  * Do not require <translation> for validation unless strict
  * Do not require <update_contact> for validation unless strict
  * add UPL short name to SPDX conversion
  * Update the SPDX license list to v3.5
  * as-compose: Remove relative path from icon names
  * Allow non-desktop components to be extended
  * Only require <release> for validate, but not validate-relax
  * Allow building on Windows
  * Modernize the validation requirements
- Drop as-glib-fix-broken-appstream-files-permission.patch: fixed
  upstream.
* Thu Aug 15 2019 bjorn.lie@gmail.com
- Update to version 0.7.15:
  + Notes: The libappstream-builder shared library is no longer
    installed.
  + New Features:
  - Add as_content_rating_get_rating_ids().
  - Add as_release_set_install_duration().
  - Add as_utils_vercmp_full() for gnome-software.
  - Add support for CONTACT URLs.
  - Add support for per-release URLs.
  - Add support for SOURCE URLs.
  - Make as_content_rating_attribute_to_csm_age() public.
  + Bugfixes:
  - Add missing OARS → CSM mappings.
  - Add some thread safety to AsApp and AsStore.
  - Do not overwrite the project group using heuristics if
    already set.
  - Recognise uncompressed Arch packages.
  - Remove unnecessary gtk dependency for builder.
  - Return G_IO_ERROR_NOT_FOUND when loading fails.
  - Tokenize the ID when adding search tokens.
- Drop pkgconfig(gtk+-3.0) BuildRequires: No longer needed.
- Switch to obs_scm service, use explict tag ref in _service,
  ensure we only use released tags and drop tag offset in version.
- Drop no longer built subpackages libappstream-builder8 and
  typelib-1_0-AppStreamBuilder-1_0.
* Wed Aug  7 2019 Jonathan Kang <sckang@suse.com>
- Add as-glib-fix-broken-appstream-files-permission.patch: Do not
  preserve restrictive permissions when installing AppStream files
  (gh#hughsie/appstream-glib#312).
* Tue Oct 23 2018 bjorn.lie@gmail.com
- Update to version 0.7.14+0:
  + Set the AppStream ID from the X-Flatpak desktop key
  + trivial: Compile the DEP-11 stuff in the RPM spec file example
  + Add as_app_to_xml()
  + Add as_content_rating_add_attribute()
* Fri Oct 12 2018 bjorn.lie@gmail.com
- Update to version 0.7.13+0:
  + Add ID provides for desktop files with X-Flatpak-RenamedFrom
  + trivial: Include glib.h for G_STRINGIFY
  + Throw an error when a launchable desktop-id is invalid
  + Better debug output for appstream-compose
  + Change order of arguments in matrix-html to match status-html
  + Do not restrict the maximum number of releases allowed
    per-component
- Changes from version 0.7.12:
  + Support localised text in agreement sections
- Changes from version 0.7.11:
  + Add AS_APP_QUIRK_DEVELOPER_VERIFIED
  + store: Provide async variants of load functions
  + Escape quotes in attributes
- Changes from version 0.7.10:
  + trivial: Sync translations and remove line numbers
  + trivial: Fix a small memory leak when adding keywords manually
  + Do not require a release transaction when validating in relaxed
    mode
  + Add object type checks on the inputs of all functions
  + Add COMMITMENT file as part of GPL Common Cure Rights
    Commitment
  + trivial: Fix GObjectIntrospection markup for adding metadata
  + Do not parse firmware files
  + its: Extract release descriptions and agreement sections for
    translation
* Sat Jun  9 2018 luc14n0@linuxmail.org
- Update to version 0.7.9+0:
  + New Features:
  - Add ability to store signature filename and checksum.
  - Convert local icons found in metainfo files.
  + Bugs fixed:
  - Follow the Debian tilde usage when ordering versions.
  - Remove the refcounted string interning feature.
  - Use the launchable to find the desktop filename.
- Drop gnome-common BuildRequires: this package has no use since
  build system port to Meson.
- Update check section to work with meson.
* Wed May  2 2018 dimstar@opensuse.org
- Update to version 0.7.8+3:
  + Use the launchable to find the desktop filename when using
    appstream-builder.
  + Follow the Debian tilde usage when ordering versions.
* Mon Apr 23 2018 luc14n0@linuxmail.org
- Update to version 0.7.8:
  + New Features: as_store_get_app_by_launchable(),
    as_utils_unique_id_match(), as_version_string() for fwupd. And
    support for component agreements.
  + Bugs fixed:
  - Correctly compare version numbers like '1.2.3' and '1.2.3a';
  - Don't include the path component in the name when parsing the
    package filename;
  - If the launchable is specified don't guess it when composing;
  - Never add more than one component to the AppStream store when
    composing;
  - Veto apps that have empty OnlyShowIn=.
* Fri Mar 16 2018 dimstar@opensuse.org
- Update to version 0.7.7:
  + Use shell-extensions::uuid for custom shell extensions metadata
    key.
* Fri Mar  9 2018 dimstar@opensuse.org
- Update to version 0.7.6+git.12:
  + Always resize AppStream icons to fit the destination size.
  + Add AS_IMAGE_LOAD_FLAG_ALWAYS_RESIZE to always resize the
    pixbuf.
  + Correctly validate files using OR in the metadata_license.
  + Update the SPDX license list to v3.0.
  + Don't abort the build if pngquant fails.
  + Add custom metadata key for shell extension uuid.
  + Do not fail to validate if the timestamps are out of order.
  + Treat pngquant exit code of 98 (nothing done) as success.
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner.
* Sun Feb 11 2018 luc14n0@linuxmail.org
- Update to version 0.7.6:
  + Never include '&' in attribute values.
  + Add support for release types.
  + Fix an invalid read when using as_app_parse_data() from Python.
  + as-app-desktop: don't deference invalid lists.
- Use pkgconfig(yaml-0.1) instead of libyaml-devel: it's what meson
  actually looks for.
- Add docbook-xsl-stylesheets and gtk-doc BuildRequires to avoid
  implicit dependencies.
- Drop intltool BuildRequires: it is no longer required since
  upstream migrated to Gettext long ago, and gthread-2.0 and
  sqlite3 BuildRequires: both of them are no longer used/needed.
- Pass dep11, builder, rpm, man, gtk-doc and introspection meson
  options as true, and alpm, fonts and stemmer as false, ensuring
  the desired features are enabled and visa versa.
* Thu Jan 25 2018 dimstar@opensuse.org
- Update to version 0.7.5:
  + Add as_app_parse_data().
  + Add as_store_get_apps_by_provide().
  + Add more GObject Introspection annotations for Python.
  + Describe connection problems/HTTP errors when validating
    images.
  + Do not use an 'enable' prefix for meson arguments.
  + Don't expect an enum when really passing a bitfield.
  + Don’t fall back to en if other languages are available.
  + Explicitly require a new enough json-glib.
  + Fix a crash when calling as_release_add_location() directly.
  + Fix appstream-compose when using new-style desktop IDs.
  + Fix compile with GCab v1.0.
  + Generate icons and samples for emoji fonts..
  + Never change the default screenshot when processing AppData.
  + Support OARS v1.1 additions.
  + Use pngquant to make the application icons take up less space.
- Add pngquant Requires: new runtime dependency to make the
  application icons take up less space.
* Mon Nov 13 2017 dimstar@opensuse.org
- Update to version 0.7.4+git.3:
  + Do not try to extract duplicate files in the icon theme
    packages.
  + Fix the arithmetic when fitting an image in 16:9
* Fri Nov 10 2017 fezhang@suse.com
- Update to version 0.7.4:
  + trivial: Disable the fonts self tests in the builder
* Fri Nov  3 2017 dimstar@opensuse.org
- Update to version 0.7.3+git.20171103 (f230c8):
  + Only try to set the file permissions on regular files.
  + Add the 'hardware' requires type.
* Tue Oct 24 2017 dimstar@opensuse.org
- Update to version 0.7.3:
  + Add support for URL launchable types
  + Prefer /usr/share/metainfo as default path for metainfo files
  + Do not assign "flatpak" as an app's origin when no origin was
    found.
  + Add as_app_get_release_by_version().
  + lib/app-validate: Fix typo in variable name.
  + Write XML for newer AppStream specification versions.
  + Add as_app_get_screenshot_default().
  + Add AS_VERSION_PARSE_FLAG_USE_BCD when formatting version
    strings.
  + Add new launchable types from the 0.11 series of the spec.
  + Fix the inode mode to be sane on extracted files.
* Thu Sep 14 2017 dimstar@opensuse.org
- Update openSUSE-appstream-process: exit early if as-builder does
  not end with exit 0.
* Tue Sep  5 2017 jengelh@inai.de
- Trim and ensure neutrality of descriptions.
* Mon Sep  4 2017 dimstar@opensuse.org
- Update License to "LGPL-2.1+ AND GPL-2.0+": the client tools
  (builder, compose and util) are licenses GPL-2.0+, the library
  is LGPL-2.1+.
* Fri Sep  1 2017 dimstar@opensuse.org
- Update to version 0.7.2:
  + Allow remote icon types for desktop AppData files.
  + Do not check the suffix of <id> tags.
  + Prefer /usr/share/metainfo as default path for metainfo files.
  + build: Enable C99 support in meson.build.
  + build: Define _XOPEN_SOURCE in order to expose realpath() in
    headers.
  + libappstream-glib: Use g_ascii_strcasecmp() instead of
    strcasecmp().
  + libappstream-builder/utils: Drop an unreachable branch.
  + libappstream-glib/self-test: Add some additional checks.
* Fri Sep  1 2017 dimstar@opensuse.org
- Update to version 0.7.1:
  + Validate the <id> format according to the spec.
  + Add <id> kinds for application provides.
  + Skip loading desktop data from Snap directory.
  + Update the SPDX license list to 2.6.
  + Support CompulsoryForDesktops in YAML.
  + Have plugins link with asglib along with asbuilder.
  + meson: avoid unnecessary gdk dependency.
  + meson: introspection optional.
  + meson: Install appdata-xml.m4.
  + build: Make gperf dependency fully required.
  + Fail to validate if AppData screenshots are duplicated.
* Mon Jun 26 2017 zaitor@opensuse.org
- Update to version 0.7.0:
  + trivial: Fix a -Wpointer-sign warning.
  + Switch to the meson build system.
  + build: Improve build-api wrapper for Meson.
  + build: Add options for building API docs and man pages.
  + build: Conditionally generate man pages.
  + build: Conditionally generate the API reference.
  + trivial: Fix the autogenerated pkgconfig files.
  + trivial: Add back the Requires and Requires.private in the .pc
    files.
  + Remove the cache-id functionality.
  + trivial: Ensure HAVE_GCAB is set when libgcab is being used.
  + Add as_store_get_apps_by_id_merge().
  + trivial: Try linking the GIR file with the local
    appstream-glib.
  + Show a warning if adding keywords after the keyword cache was
    created.
  + Fix the default plugin directory used by appstream-builder.
  + Add the limits in the validation output messages.
  + trivial: Prevent crash when a sanity check fails.
  + trivial: Remove the ability to run threaded.
  + Remove functionality processing an old metadata file.
  + trivial: Fix a warning message to be more clear.
  + trivial: Fix a variable with a misleading name.
  + Actually return failure if the AsbTask fails.
  + Add the missing shell-extension plugin.
  + trivial: Remove autotools fixups no longer required.
  + Do not enforce that the project_group is a valid
    environment_id.
  + Do not add the GNOME-Software-specific categories or icons by
    default.
  + Enable Travis CI for Fedora 25 and Debian Stretch.
  + Allow compiling with newer versions of meson.
  + trivial: Fix the meson version compare value.
  + Fix regression when building component types without icons.
  + as-app-builder: Don't cast gsize to guint32 when getting file
    length.
  + trivial: Fix an error message in news-to-appdata.
  + Do not write a timestamp when using news-to-appdata.
  + trivial: Ensure every app has format set before adding to
    store.
  + trivial: Fix up several small memory leaks.
- Add meson BuildRequires and switch autotools macros configure,
  make and makeinstall to meson, meson_build and meson_install
  following upstream switch to Meson build system.
* Mon Jun 26 2017 zaitor@opensuse.org
- Update to version 0.6.13:
  + Add functions for getting the AsApp search match.
  + Add functions for getting the AsStore search match.
  + Allow using the app origin as a search keyword.
  + trivial: Use the new custom tag in the self tests.
  + Add support for <launchable>.
  + trivial: Fix up some broken links in the generated
    documentation.
  + Add support for icon scaling.
  + Add as_utils_guid_from_data().
  + Support non-numeric version numbers correctly.
  + trivial: Do not store the .shell-extension prefix in the search
    cache.
  + Casefold all stemmed entries.
  + trivial: Add a regex command to appstream-util for testing
    firmware versions.
  + Add a 'check-component' command to appstream-util.
  + Add as_app_remove_category().
  + Add as_app_remove_kudo().
* Mon Apr 24 2017 dimstar@opensuse.org
- Update to version 0.6.12:
  + Copy hash table keys from AsApp to avoid them being used after
    they've been freed.
  + Validate kudos in AppData and AppStream files.
  + Fix the predicate comparison when using globs in metainfo
    files.
* Tue Mar 21 2017 zaitor@opensuse.org
- Update to version 0.6.11:
  + Don't crash when using 'appstream-util show-search-tokens'.
  + Fix a problem with appstream-compose with older AppData files.
  + Make content_rating a requirement for any component with the
    'Game' category.
  + trivial: Update app ID rename list.
  + Revert "Enable the stack protection in local builds".
  + Show a warning if a desktop file is not found when required.
  + trivial: Report the archive filename if it cannot be opened.
  + Fix compile with -Wdiscarded-qualifiers.
  + Parse small version numbers correctly.
  + trivial: Split out some common functionality.
  + trivial: Find .pak translations in all libdirs.
  + Add initial support for Mozilla .xpi translations.
* Sat Mar 11 2017 zaitor@opensuse.org
- Update to version 0.6.10:
  + trivial: post release version bump.
  + Ignore <p></p> in AppStream markup.
  + its: add <developer_name> to tags extracted for translation.
  + as-node: Add back as_node_context_{get,set}_source_kind.
* Tue Feb 28 2017 dimstar@opensuse.org
- Update to version 0.6.9:
  + Revert "Require name and summary for validate-relax".
  + Fail to validate if the release children are in the wrong
    order.
  + Fail to validate if any release is in the future.
  + Add AsFormat object.
  + Add new API to GsApp to handle AsFormat objects.
  + Do not set the AsApp state using the AsRelease state.
  + Recalculate the state when formats are added or removed from a
    AsApp.
  + Deprecate app_set_source_file() and app_set_source_kind().
* Thu Feb  2 2017 zaitor@opensuse.org
- Update to version 0.6.8:
  + Do not ignore type=replace merge components.
  + Tighten a rule that classifies apps as web-apps.
  + Support reading metainfo.xml files when using
    appstream-compose.
  + Read and write the <custom> tag.
  + appstream-compose: Support appdata with no desktop files.
  + AsStore: hold a ref in hash_unique_id to avoid use-after-free.
  + trivial: profile: Free mutex resources in finalize().
  + trivial: Update app ID rename list.
  + store: Fix use after free with hash table keys.
  + Add a destructor for AsRefString.
  + Make gperf a hard dep.
  + Fix the build with gperf 3.1.
  + Ignore -Wconversion and -Wsign-conversion warnings from
    generated file.
  + Require name and summary for validate-relax.
  + util: Add a dummy update_contact to appdata-from-desktop.
  + trivial: Fix a crash when removing apps from the store.
  + Release version 0.6.8.
- Add gperf BuildRequires: New dependency.
* Thu Jan 12 2017 dimstar@opensuse.org
- Update to version 0.6.7:
  + Scan /usr/share/metainfo as well when building appstream-data.
  + Resolve relative symlinks when extracting archives.
  + Add a test for extracting relative symlinks.
  + Add AsRequire as a way to store runtime requirements.
  + Support glob and regex matches in requires compare tags.
  + Update the SPDX licence list to v2.5.
  + Remove invalid SPDX licenses from content license lookup table.
  + Revert "Remove invalid SPDX licenses from content license
    lookup table".
  + Add support for "+" operator at the end of SPDX license
    identifiers.
  + Fix dep extraction when multiple versions are available.
  + Recursively add subpackage deps into the main package.
  + Allow loading application XPM icons.
  + Write log files in a better way.
  + Fix a crash when using as_release_get_location_default().
  + build: Enable C99 support in configure.ac.
  + Limit recursive deps lookup to the same source package.
  + Only fail to validate <icon> in AppData desktop components.
  + Release version 0.6.7.
* Fri Dec 16 2016 zaitor@opensuse.org
- Update to version 0.6.6:
  + trivial:
  - Remove two unused variables.
  - Use g_autoptr to avoid a Coverity warning.
  - Do not leak the entry if the file cannot be read.
  - Fix the self tests now we're stemming the tag cache.
  - Show a total process time when using appstream-util
  - -profile.
  - Don't split the text every time in the XML parsing hot path.
  - Add as_ref_string_debug().
  - Add as_ref_string_new_static().
  - Fix a tiny memory leak when escaping cdata.
  - Fix unused variable warnings.
  - Use -Wunused.
  - Remove an ununsed variable.
  - Remove a tiny compiler warning.
  - Do not attempt to parse unknown tags when converting.
  - Don't include trailing whitespace from AppData files.
  - Output the release state if the export is trusted
  - Add some asserts to shut up clang.
  + Check the return value of the stat call.
  + Do not save the XML attributes if the node or parent node is
    being ignored.
  + Don't recommend use of DISTCHECK_CONFIGURE_FLAGS.
  + Deduplicate the AsNode attribute key and value using a hash
    table.
  + Deduplicate common AsNode cdata sections for some tag types.
  + Dedupliate nonstandard tag names using a hash table.
  + Detect invalid files in the libyaml read handler.
  + Don't export NULL tags from AppData file.
  + Add a refcounted overloaded C string object.
  + Use refcounted strings in all objects.
  + Lazy load structures in AsRelease.
  + Use refcounted strings as the localised key.
  + Lazy load the screenshot captions storage.
  + Allocate the release sizes at runtime.
  + trivial: Use a finer threshold when performing massif.
  + Cache the stemmer results in a hash table.
  + Add support for ONLY_NATIVE_LANGS when parsing yaml files.
  + Use full RELRO in the client executables.
  + Enable the stack protection in local builds.
  + Set a better icon for codecs.
  + Make AsRefString thread safe.
  + Fix one more thread safety issue with AsRefString.
  + Don't regenerate .pot files with every build.
  + Don't add <languages> for addons.
  + Don't add <kudos> for addons.
  + Don't add <provides> for addons.
  + Don't add <releases> for addons.
  + Do not absorb core addons into the main application.
  + Add Geary to the app id fallbacks.
  + Add AS_APP_QUIRK_IS_PROXY.
  + Add as_release_state_to_string().
  + Subsume the AppData releases into AppStream items.
* Mon Nov  7 2016 dimstar@opensuse.org
- Update to version 0.6.5:
  + Trivial changes:
  - Allow the stemmer to be disabled at runtime for testing.
  - Allow priming the search cache using a NULL search value.
  - Allocate less strings when generating the token cache.
  - Show threaded tasks in bold in the profile output.
  - Speed up checking token validity by a few ms.
  - Restore behaviour compatibility to fix self tests.
  - Add API to set the smallest recorded delay time.
  - Only load native languages from desktop files when the flag
    is set.
  - Output profiling infomation to stderr.
  - Unsingleton AsStemmer and use a shared instance in AsStore.
  + Do not sent a REMOVED signal when deleting a transient temp
    file.
  + Process file changes when an attribute changes.
  + Handle files being moved into monitored AppStream directories.
  + Add a 'watch' command to appstream-util.
  + Monitor missing AppStream directories.
  + Revert "trivial: Restrict the bundle kind when parsing local
    files".
  + Ensure the component scope is set when loading yaml files.
  + Always copy the installed state when replacing AppData with
    AppStream.
  + Merge also the metadata when merging two apps.
  + Add app-removed, app-added and app-changed signals to AsStore.
  + Only transliterate when the locale requires it.
  + Add as_store_load_search_cache().
  + Load the search token blacklist into a hash table.
  + Use multiple threads to load the search cache.
  + Only load native languages when parsing AppStream data.
  + Allow the client to control what search fields are indexed.
* Thu Oct 13 2016 dimstar@opensuse.org
- Update to version 0.6.4:
  + trivial:
  - post release version bump.
  - Allow detailed profiling when using as_store_from_file().
  - Make as_profile_clear() threadsafe.
  - Make as_profile_dump() threadsafe.
  - Fix building AppStream metadata when using local files.
  - Fix two potential deadlocks in the AsProfile code.
  - Add some sanity checks to the unique-id hash tests.
  - Fix a couple of warnings with -Wundef.
  + Add support for AppImage bundles.
  + Fix building metadata on repos with mixed architecture content.
  + Add as_store_add_apps().
  + Add as_profile_prune() for limiting the profiling output.
  + Add as_profile_set_autoprune() for automatically limiting the
    profiling output.
  + Fix the CSM rating age calculation.
  + Add as_content_rating_get_value().
  + Fix setting the origin for Flatpak user repos.
  + Never inhierit Name and Comment when using appstream-compose.
  + Don't show a critical warning on invalid yaml file.
  + Fix a small memory leak when parsing yaml files.
  + Add functions to build and validate an AppStream ID.
  + Add flag to only load uncompressed files into a store.
  + Allow filtering applications based on merge type.
  + Release version 0.6.4.
* Mon Sep 19 2016 dimstar@opensuse.org
- Update openSUSE-appstream-process: do not rename the various
  appstream files to contain the sha hash in their filename: zypp
  is not (yet) able to cope with this (boo#999047).
* Sun Sep 11 2016 zaitor@opensuse.org
- Update to version 0.6.3:
  + trivial:
  - Fix a -Wundef compiler warning.
  - Sync example spec file with downstream.
  - Do not write <icon type=unknown> for unknown types.
  - Fix up tests after the -lang auto-dep commit.
  + Support components with merge=replace rules.
  + Add a component kind of 'driver'.
  + Refactor the desktop file icon loading code.
  + Convert the built unknown icons to the correct kind depending
    on the action.
  + Add -lang package as a dependency in order to properly detect
    translations (gh#hughsie/appstream-glib#135).
  + Add an easy way to add a modalias to an existing file.
  + Add an easy way to add a language to an existing file.
- Drop appstream-glib-lang.patch: Fixed upstream.
* Thu Sep  8 2016 dimstar@opensuse.org
- Update openSUSE-appstream-process:
  + Do not include -failed.xml.gz: people complain about the
    additional ~ 100KB zypp downloads on a repodata refresh at 'no
    value for them'. The failed.xml.gz is not needed for regular
    operations, but was a great help for packagers to find out why
    their app was vetoed. They will need to find different ways to
    get this info.
  + Rename appdata-screenshots.tar to appdata-screenshots-$HASH.tar
    to help mirrorbrain offload this file to mirrors.
* Mon Sep  5 2016 dimstar@opensuse.org
- Add appstream-glib-lang.patch:  Add -lang package as a dependency
  in order to properly detect translations.
* Mon Sep  5 2016 dimstar@opensuse.org
- Update to version 0.6.2:
  + New Features:
  - Add a hash function specifically designed for unique-ids.
  - Add AS_BUNDLE_KIND_CABINET.
  - Remove the inf parsing from appstream-glib.
  + Bugfixes:
  - Check if icon name is unset before checking the prefix.
  - Do not merge all LangPack entries.
  - Do not require an icon from LOCALIZATION kind.
  - Do not use the deprecated GNOME_COMPILE_WARNINGS.
  - Do not use the prefix check when parsing YAML.
  - Fix gcc shift warnings on 32 bit platforms.
  - Ignore system datadirs that are actually per-user.
  - Invalidate the unique-id if any of the parts are changed.
  - Make upgrade check for SPDX license string.
  - Pay attention to errors from libyaml
    (gh#hughsie/appstream-glib#129).
* Tue Aug 16 2016 dimstar@opensuse.org
- Update to version 0.6.1:
  + trivial: post release version bump.
  + Add Sugar as a valid desktop environment
    (gh#highsie/appstream-glib#118).
  + Do not save the 'X-' prefixed keys to the AppStream metadata.
  + correct issue in transifex link
    (gh#hughsie/appstream-glib#119).
  + trivial: Factor out a soon-to-be-shared function.
  + trivial: Add two more renamed desktop IDs.
  + Add two new GCC warnings and fix up signed/unsigned issues.
  + Be more careful choosing warning flags.
  + trivial: Fix some gtk-doc markup.
  + Add AsReview.
  + trivial: Remove AsReview.karma as it's implementation specific.
  + trivial: Update git.mk to latest upstream copy.
  + Port away from intltool.
  + Do not split up the main AudioVideo category.
  + Don't change ABI when built with/without gperf
    (gh#hughsie/appstream-glib#123).
  + Avoid unsatisfiable development dependency when built without
    libgcab (gh#hughsie/appstream-glib#122).
  + trivial: Post branch version bump.
  + Remove specific support for flatpak.
  + trivial: Fix some gtk-doc markup.
  + trivial: Add AS_BUNDLE_KIND_SNAP.
  + trivial: Add AS_BUNDLE_KIND_PACKAGE.
  + Add as_app_equal().
  + Add as_app_set_branch().
  + Include the architecture in the equality check.
  + Include the origin in the equality check.
  + Include the scope in the equality check.
  + Include the distribution system in the equality check.
  + trivial: Fix the origin name when using the symlink name.
  + trivial: Fix the flatpak scope when using the symlink name.
  + trivial: Show the unique ID when using 'appstream-util search'.
  + Add as_store_get_app_by_unique_id().
  + Enable globbing in as_app_equal().
  + Restrict addons to the same scope and bundle kind.
  + Include the version in the equality check.
  + Add as_utils_unique_id_build().
  + Allow multiple components with the same AppStream ID in the
    AsStore.
  + trivial: Don't write invalid width and height properties.
  + trivial: Add some initial self tests for
    AS_STORE_ADD_FLAG_USE_UNIQUE_ID.
  + Skip DEP-11 tests when DEP-11 is not enabled.
  + as_store_from_file_internal: don't redundantly monitor files.
  + as_store_from_file_internal: set up path data for the file
    itself.
  + Use an array of application objects in the ID hash.
  + trivial: Use the unique ID in the dedupe logs.
  + trivial: Fix critical warning when parsing qm files without a
    domain.
  + Add support for Google .PAK file to extract the <lang> data for
    apps.
  + Always use wildcards when adding apps to the store.
  + Add a fast as_utils_unique_id_equal() to compare IDs for
    equality.
  + Add as_utils_unique_id_valid() and use it before parsing.
  + trivial: Fix as_utils_unique_id_equal() to work with multiple
    globs.
  + Support merge components.
  + Use a more relaxed unique-id match for merge components.
  + Add some more validation checks for keywords.
  + trivial: Use the existing quirk as it can be made useful again.
  + trivial: Parse the unique_id correctly when searching.
  + trivial: Check if the flatpak ID is valid before using.
  + Only subsume a safe subset from merge components.
  + trivial: Update to latest translations from transifex.
  + trivial: Switch from Transifex to Zanata.
  + trivial: Decompress .pak files when getting languages.
  + Don't include the version in the unique ID.
  + Don't include the architecture in the unique ID.
  + Allow subsuming each property individually.
  + Add SUSE-Public-Domain to License map
    (gh#hughsie/appstream-glib#126).
  + Add the TRANSLATE URL kind.
  + trivial: Fix some gtk-doc markup.
  + No validation failure for lots of releases.
  + trivial: Be a bit more helpful when reporting validation
    warnings.
  + trivial: Fix the comment text for 'help' when upgrading.
  + Print max caption length when validating.
  + trivial: Allow setting the output trusted mode using an
    environment variable.
  + trivial: Don't add a duplicate <developer_name> when it exists
    already.
  + Ensure predictable output order of XML attributes.
  + Support AppStream merge components.
  + Add support for application suggestions.
  + Make asglib read current component-type names.
  + yaml: Read all component types, not just desktop-apps.
  + Add console-app component type.
  + trivial: Fix validation of console-application components.
  + Release version 0.6.1.
* Thu Jul 14 2016 zaitor@opensuse.org
- Update to version 0.5.17:
  + trivial: post release version bump.
  + Fix gtk-doc build when builddir != srcdir.
  + Optionally use libstemmer for keyword stemming.
  + trivial: Do not include the prefix in the id-filename.
  + trivial: Disable libstemmer by default.
  + trivial: Get rid of useless internal-only gtk-doc markup.
  + trivial: Fix 'make check' without libstemmer.
  + Fall back to the country code in as_app_get_language().
  + Add an AS_STATE_PURCHASABLE constant so we can support
    purchasing apps.
  + Add an AS_STATE_PURCHASING constant.
  + monitor: Use non-deprecated glib API for monitoring renames.
  + trivial: Fix a compiler warning with libstemmer disabled.
  + store: Don't emit a warning when flatpak user directory doesn't
    exist.
  + Correct disabling of timestamps for gzip.
  + trivial: Remove the X- hack from parsing the category list.
  + Add external (X-*) keys of an app's desktop file as metadata
    AsApp.
  + Fix missing keywords in the previous commit.
  + Don't add multiple categories for apps with AudioVideo.
  + Release version 0.5.17
* Tue Jun 14 2016 dimstar@opensuse.org
- Update to version 0.5.16:
  + Add yast2-branding-openSUSE if an app depends on yast2.
  + trivial: post release version bump.
  + Fix g_ptr_array_sort use.
  + Do not rename a category ID in AsApp.
  + Never allow NULL to be added to AsApp string array.
  + Allow setting the id prefix and origin using a symlink file
    name.
  + trivial: Do not load Flatpak repos when searching.
  + Correctly detect new AppStream applications in new directories.
  + Add elementary to list of project groups.
  + trivial: Fix make distcheck.
  + trivial: Fix several issues to ensure changed signal are sent.
  + Load metainfo files if present.
  + Release version 0.5.16.
- Drop
  0001-Add-yast2-branding-openSUSE-if-an-app-depends-on-yas.patch:
  fixed upstream.
* Mon May 23 2016 dimstar@opensuse.org
- Update to version 0.5.15:
  + trivial: post release version bump.
  + Add AS_APP_QUIRK_HAS_SHORTCUT.
  + trivial: Try to shut up libasn.
  + Ignore files with invalid suffixes when building installed
    stores.
  + Add AS_APP_QUIRK_NOT_LAUNCHABLE.
  + trivial: Add three more apps to the ID fallback table.
  + trivial: Fix a critical warning when an AppData file has
    invalid input.
  + Fall back to the icon name for LOCAL icon types.
  + yaml: Make icon parser spec compliant.
  + trivial: Add a work-around for the new libreoffice in the
    builder.
  + trivial: Set missing icon prefix for cached YAML.
  + Sort archive contents by name for repeatable results.
  + Omit timestamp from gzip compressed files.
  + README.md: add note for glob usage.
  + README.md: wrap at 80 chars.
  + trivial: Add some more debugging to debug an issue.
  + Rename the xdg-app support to the new name: Flatpak.
  + trivial: Add some support for flatpak self tests.
  + Addons can have duplcate names.
  + Show the app name when complaining about missing description in
    the metadata.
  + Revert "trivial: Add some support for flatpak self tests".
  + Always add /var/lib/flatpak/appstream as a possible Flatpak
    path.
  + Add all applications for all architectures when loading
    Flatpak.
  + Set the architecture of discovered Flatpak apps.
  + Correctly set the architecture on newly discovered
    applications.
  + Save the ID prefix in more places.
  + Release version 0.5.15.
- Drop 0001-Omit-timestamp-from-gzip-compressed-files.patch and
  0001-Sort-archive-contents-by-name-for-repeatable-results.patch:
  fixed upstream.
* Thu May 19 2016 hpj@suse.com
- Update to GNOME 3.20.2 (FATE#318572).
* Tue May  3 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
* Mon May  2 2016 stefan.bruens@rwth-aachen.de
- Make output of appstream-builder repeatable (boo#977885):
  + 0001-Sort-archive-contents-by-name-for-repeatable-results.patch
  + 0001-Omit-timestamp-from-gzip-compressed-files.patch
* Tue Apr 26 2016 zaitor@opensuse.org
- Update to version 0.5.14:
  + Ignore desktop files with X-AppStream-Ignore.
  + Add search-pkgname to appstream-glib.
  + Add AS_APP_QUIRK_NEEDS_REBOOT.
  + Fall back to searching in as_store_get_app_by_pkgname().
  + Add AS_APP_QUIRK_NOT_REVIEWABLE.
  + Search /usr/share/metainfo for local files.
  + trivial: Fix critical warning when validing broken AppStream
    files.
  + Add the Audio+Video categories from AppStream XML too.
  + Add as_screenshot_get_image_for_locale().
* Thu Apr 14 2016 dimstar@opensuse.org
- Require the main-package by the -devel package: the AS-utils are
  expected to be available to a developer.
* Mon Apr  4 2016 dleuenberger@suse.com
- openSUSE-appstream-process: No longer pass --api-version to the
  appstream-builder call (boo#973385).
* Sat Apr  2 2016 zaitor@opensuse.org
- Update to version 0.5.13:
  + trivial: post release version bump
  + Also filter YAML apps before adding to the store
  + trivial: Fix a gtk-doc markup warning
  + Support more DEP11 YAML markup
  + Always veto anything with X-Unity-Settings-Panel
  + Use a wildcard for the font preview checksum
  + Enforce the requirement of AppData for
    'Categories=DesktopSettings'
  + Add as_store_remove_apps_with_veto()
  + trivial: Only remove apps with a veto when specified
  + Do not hardcode x86_64 when searching for xdg-app metadata
  + Release version 0.5.13
* Sat Apr  2 2016 zaitor@opensuse.org
- Update to version 0.5.12:
  + trivial: post release version bump
  + trivial: Add missing gtk-doc
  + Add support for content ratings
  + trivial: Add some more OARS CSM ages
  + Split up AudioVideo into two categories
  + Add as_app_get_id_no_prefix()
  + Add AS_APP_QUIRK_MATCH_ANY_PREFIX
  + Add as_store_get_app_by_id_ignore_prefix()
  + Add as_store_get_apps_by_id()
  + Merge duplicate AppStream component entries
  + Add as_app_has_compulsory_for_desktop()
  + Add a merge-appstream command to appstream-util
  + Release version 0.5.12
* Tue Mar  8 2016 dimstar@opensuse.org
- Update to version 0.5.11:
  + trivial: post release version bump
  + trivial: Do not require icons for generic component types.
  + Fix ordering of parameters to as_store_search_app_info.
  + Add AS_APP_KIND_LOCALIZATION.
  + Fix crash when validating files containing invalid remote URIs.
  + Add as_markup_import()
  + Add support for GNOME Shell extensions..
  + Do not tokenize the application ID or package name.
  + trivial: When searching look in the user app-info dirs too.
  + Do not mark all subsumed applications as installed.
  + trivial: Fix FALSE/NULL confusion spotted with GCC6.
  + trivial: Fix a tiny introspection warning.
  + trivial: Fix another compile warning with GCC6.
  + Add a AsMarkupConvertFormat to as_markup_import().
  + Split out as-markup into a new source file.
  + Add as_utils_string_replace().
  + trivial: Prefer <ul> over <ol> when the list start is unknown.
  + Support importing HTML text using as_markup_import().
  + Add a 'markup-import' command to appstream-util for testing
    text import.
  + Implement DEP-11 MediaBaseUrl support.
  + Tokenize names like 'half-life' into two tokens for searching.
  + Release version 0.5.11.
- Add pkgconfig(json-glib-1.0) BuildRequires: new dependency.
* Tue Mar  1 2016 zaitor@opensuse.org
- Update to version 0.5.10:
  + Add AS_APP_KIND_SHELL_EXTENSION.
  + Add AS_APP_KIND_OS_UPDATE.
  + trivial: Display the search sort key in hex.
  + Do not tokenize mimetypes.
  + Support loading XML files using as_store_from_bytes().
  + trivial: Fix critical warning for xdg-app bundles.
  + Add AsAppQuirk.
  + trivial: Add AS_APP_QUIRK_HAS_SOURCE.
  + Add a 'split-appstream' command to appstream-util.
  + Release version 0.5.10.
* Wed Feb 17 2016 dimstar@opensuse.org
- Update to version 0.5.9:
  + trivial: post release version bump
  + Fix dates in NEWS - It's 2016!
  + Add missing G_BEGIN_DECLS in libappstream-glib/as-tag.h.
  + Accept FSFAP as a valid metadata license
  + Update the SPDX license list
  + Fix a validation error for metainfo files with descriptions
  + store: Keep track of which appinfo dirs are added and never
    re-add them
  + store: Pick up newly added appinfo dirs for xdg-app remotes
  + trivial: Fix a couple of small memory leaks
  + Release version 0.5.9
* Wed Feb 17 2016 dimstar@opensuse.org
- Update to version 0.5.8:
  + trivial: post release version bump
  + trivial: Remove the hardcoded hack for nautilus
  + trivial: Remove some dead code
  + trivial: Remove a warning for no recent upstream release
  + trivial: Remove the veto for ConsoleOnly
  + Use the project_group heuristics when parsing AppData files
  + Remove the hardcoded rule for xfdashboard as it has been
    reported upstream
  + Only load supported icon kinds when using appstream-compose
  + trivial: Remove support for old-style firmware GUIDS-as-IDs
  + trivial: Relax the XML header requirement
  + Reject an invalid project group when parsing
  + Use heuristics when building metadata with an AppData file
  + trivial: Fix linking error when building appstream-compose
  + Add support for per-user and system-wide xdg-app installed
    stores
  + Set the xdg-app origin using the filename
  + Add a modify command to appstream-util
  + trivial: Add the missing AsBundle to gtk-doc
  + Add AsTranslation to support <translation> tags in AppData
    files
  + Fix a regression in the icon_path logic from the xdg-app merge
  + Support multi-line copyright statements
  + Allow setting state on AsRelease objects
  + Support the QT translation system
  + Parse the sections in the QM file format
  + trivial: Fix regression with AppStream metadata in xmls
  + Add support for the GENERIC component kind
  + Add a flag for skipping invalid AppStream files
  + Remove support for Ubuntu app-install data
  + Set the xdg-app origin on the store, and only set app origin to
    the remote name
  + trivial: Fix up self tests after generic kind
  + Move the kudo and provides autodetection to libappstream-glib
  + Use predictable sorting when outputting <provides>
  + trivial: Do not require icons for generic or runtime kinds
  + Show the source of the 'appstream-util check-root' failure
  + Do not respect the icon_root when using as_store_from_file()
  + Blacklist the xdg-app AppStream data as the correct data is
    added manually
  + trivial: Support loading the xdg-app AppStream data from inside
    the sandbox
  + trivial: Prefer the xmls icon rule over the xdg-app one
  + dep11: Support stock icons
  + Escape data before writing to an HTML file
  + Ignore temp and hidden files in AsMonitor
  + Release version 0.5.8
* Sat Feb  6 2016 dimstar@opensuse.org
- openSUSE-appstream-process: fix very stupid typo. 4 eyes is not
  enough.
* Fri Jan 29 2016 dimstar@opensuse.org
- openSUSE-appstream-process: use specific temporary/cache
  directories between calls. Otherwise, icons extracted from a
  previous run bleed into the next one.
* Fri Jan 29 2016 dimstar@opensuse.org
- Update to version 0.5.7:
  + trivial: post release version bump.
  + Detect web-apps which are added as .desktop files.
  + Make the check for screenshot equality more robust.
  + trivial: Fix self tests after the xdg-app fixes.
  + trivial: Never write empty <screenshot/> tags.
  + Move the blacklisted application list to the front-end client.
  + ostree: Work around threadsafety issue with
    g_get_language_names.
  + ostree: Remove unnecessary workarounds for bundle paths.
  + Move the gettext parsing to libappstream-glib.
  + trivial: Use G_DEFINE_QUARK.
  + Only build the test firmware files when using
  - -enable-firmware.
  + Allow disabling font support with --disable-fonts.
  + Allow multiple NLS domains to be specified when searching.
  + Add as_image_load_filename_full().
  + Support date=iso8601 attributes in <release> markup.
  + Add appstream-compose.
  + Remove all traces of ostree.
  + Remove the GStreamer plugin.
  + Remove the GIR and GResource, nm and KDE-specific plugins.
  + trivial: Fix 'make distcheck' with the new gettext test files.
  + trivial: Fix building firmware after the ostree removal.
  + Release version 0.5.7.
* Mon Jan 18 2016 dimstar@opensuse.org
- Update to version 0.5.6:
  + trivial: post release version bump.
  + Accept various 'or later' metadata content licenses.
  + libappstream-glib: Add the runtime ID kind.
  + trivial: Fix a small memory leak when parsing debs.
  + Assume a release value of '0' when unset.
  + Fix AppStream generation when using duplicate .deb packages.
  + Check the project_group when validating.
  + Check name uniqueness when validating AppStream data.
  + trivial: Mark some more strings as translatable.
  + Install gettext ITS rules.
  + Cull the application blacklist now we depend on AppData files
    for the builder.
  + trivial: Add the gettext files to the example spec file.
  + Set a validation failure for files using <updatecontact> when
    being strict.
  + Allow dumping inf files using appstream-util.
  + trivial: Fix the Since: value on as_utils_is_spdx_license().
  + Always blacklist desktop files for uninstalling software.
  + Automatically add missing .inf types as required.
  + trivial: Fix the self tests after the blacklist cull.
  + Prefer stock icons when using as_app_get_icon_default().
  + package-ostree: Init NEVRA on open otherwise we don't get the
    right tmpdir name.
  + asb-package-ostree: Fix things up for xdg-app use.
  + ostree: Allow specifying a particular arch only.
  + Release version 0.5.6.
* Sun Dec 20 2015 zaitor@opensuse.org
- Update to version 0.5.5:
  + Add a AS_APP_STATE_UPDATABLE_LIVE constant so we can support
    live updates.
  + Allow update_contact to be output in very limited conditions.
  + Log when we auto-add kudos or keywords.
  + Add the package name as another application search token.
  + Add as_utils_license_to_spdx().
  + Only use the package license when not provided by the AppData
    file.
  + trivial: Fix a compiler warning.
  + Fix a crash when tokenizing a NULL string.
* Wed Nov 25 2015 zaitor@opensuse.org
- Update to version 0.5.4:
  + New Features: Add as_utils_version_from_uint16().
  + Bugfixes: Generate GUID values according to RFC4122.
- Add pkgconfig(uuid) BuildRequires: New dependency.
* Tue Nov 17 2015 dimstar@opensuse.org
- Update to version 0.5.3:
  + trivial: post release version bump.
  + trivial: Sync example spec file with downstream.
  + Strip Win32 and Linux paths when decompressing firmware.
  + Return the correct error when the desktop file has no
    [Desktop Entry] group.
* Tue Nov 17 2015 dimstar@opensuse.org
- openSUSE-appstream-process: Do not produce html files;
  the biggest chunks of apps are done and the few users still
  caring can produce them anytime out of the provided .xml.gz
  files.
* Sat Nov  7 2015 zaitor@opensuse.org
- Add pkgconfig(libgcab-1.0) BuildRequires: New dependency.
* Mon Nov  2 2015 dimstar@opensuse.org
- Update to version 0.5.2:
  + Do not overwrite the AppData URL with the one from the package.
  + Do not ever store the KDE x-test locale data.
  + Require AppData files to be present in the AppStream metadata.
  + Use a sensible warning when processing desktop files with
    NoDisplay=true.
  + Simplify veto messages for missing <name> and <summary>.
  + Fix a typo in command name.
  + Support super-HiDPI icons like shipped in Hedgewars.
  + trivial: Do not subsume vetos if AS_APP_SUBSUME_FLAG_PARTIAL is
    used.
  + Accept a '0x' hexidecimal prefix when parsing a component.
  + Always use a dotted-decimal representation of the version.
  + Add AsProfile for speed profiling.
  + trivial: Show the path when profiling
    as_store_load_installed().
  + as_profile: Non-void function should return a value.
  + trivial: Symbolic stock icons are valid.
  + Add an --enable-profile option to appstream-util.
  + Remove the long-obsolete appdata-validate tool.
  + Add as_profile_set_autodump().
  + Monitor /usr/share/applications for apps without AppData when
    using watch flags.
  + Add as_markup_validate() to check descriptions.
  + Allow as_markup_convert() to ignore errors.
  + Always escape AppStream descriptions when doing passthrough.
  + Add support for <size>.
  + Add the ability to attach blobs of data to AsRelease objects.
  + Add the ability to parse .cab archives as AppStream stores.
  + Use AsStoreCab to read .cab files when building metadata.
  + Fix crash in validator when processing '<li></li>'.
  + Do not fail to install firmware if DriverVer is not set.
  + Use as_utils_vercmp() to be correctly check versions for
    equality.
  + Try harder to deal with icons that have extension or full path
    listed.
  + Only accept UNIX paths for files in cab files.
  + Do not use the DriverVersion for the inf file version.
  + Use a MS-style version number when parsing a hex version.
  + libappstream-glib: Do not parse ISO dates as uint32 version
    numbers.
  + Do not attempt to parse the version in
    as_release_set_version().
  + Use a wildcard in the self tests to ignore GCab-generated hash
    differences.
* Wed Sep 16 2015 opensuse-packaging@opensuse.org
- Update to version 0.5.1:
  + trivial: post release version bump
  + Do not blacklist the 'desktop' token as this is sometimes
    legitimate
  + Support SPDX IDs with the LicenseRef prefix
  + Support the SPDX 'NONE' and 'NOASSERTION' keywords
  + trivial: Fix build warning in make check
  + trivial: Fix a build error when running under ninja
  + trivial: Remove prototype with no method
  + Allow a filter filename to be used with the builder
  + Introduce _cleanup_free_libc_ cleanup attribute
  + Avoid using PATH_MAX
  + Revert "Allow a filter filename to be used with the builder"
  + Ignore empty AppStream XML files
  + Add a few KDE applications that have changed desktop ID
  + Don't show mangled version numbers as negatives
  + Add another GNOME application that changed IDs
  + libappstream-glib: Port to G_DECLARE_DERIVABLE_TYPE macro
  + libappstream-builder: Port to G_DECLARE_DERIVABLE_TYPE macro
  + Use GLib's cleanup functions instead of libgsystem's
  + trivial: Fix the build
  + trivial: Remove any support for installed appdata-extra files
  + trivial: Drop as-cleanup.h include where not needed
  + Do not fail to validate firmware in AppStream with no
    screenshots
  + Use glib's cleanup functions for libsoup as well
  + Use glib's cleanup functions for GString
  + Add support for release urgency
  + Don't reallocate malloc'd memory with g_malloc
  + Use specific types to remove the last _cleanup_free usage
  + Use the typedef'd name in the code to help readability
  + trivial: Fix --enable-ostree build
  + trivial: Fix gcab generated checksums
  + Release version 0.5.1
* Tue Sep  1 2015 dimstar@opensuse.org
- openSUSE-appstream-process: compress the status html files
  (boo#942985).
* Thu Aug 13 2015 zaitor@opensuse.org
- Update to version 0.5.0:
  + Show a better error message when there's not enough text
    before <ul>.
  + Add two functions from fwupd for checking GUID strings.
  + Fix the name of the D-Bus session enum.
  + trivial: Remove unused prototype.
  + Add support for the flashed firmware provide kind.
  + Find the application in a store by the provide value.
  + trivial: Do not run the slow GFileMonitor tests by default.
  + Remove support for lower than AppStream 0.8.
  + Remove an unused exported method.
- Rename libappstream-builder7 to libappstream-builder8 and
  libappstream-glib7 to libappstream-glib8, following upstreams
  soname change.
* Thu Jul 23 2015 zaitor@opensuse.org
- Update to version 0.4.1:
  + New Features:
  - Add a 'compare' command to appstream-util.
  - Add a 'mirror-local-firmware' command to appstream-util.
  - Add a flag to relax the AppData Category=Settings
    requirement.
  - Add a flag to use non-optimal data sources when building
    metadata.
  - Add am 'incorporate' command to appstream-util.
  - Add two flags to veto-ignore to relax the requirements for
    metadata.
  + Bugfixes:
  - Be less strict when loading incorrect AppData files.
  - Do not duplicate <location> tags within a release.
  - Do not expect the INF ClassGuid to be the ESRT GUID.
  - Don't crash when parsing a <release> with no description.
  - Fix a potential crash spotted by clang.
  - Fix autogen with latest Intltool.
  - Ignore the prefix when loading system-wide AppStream
    information.
  - Include <pkgname> when writing the ignored metadata.
  - Only write the release timestamp if non-zero.
  - Remove the AppData veto when incorporating metadata.
  - Search harder when using AS_ICON_LOAD_FLAG_SEARCH_SIZE.
  - Sort multiple <icon> entries by name.
  - Update the SPDX licence list to v2.0.
  - When building metadata with the use-fallback flag accept
    legacy icon names.
* Mon Jul 13 2015 dimstar@opensuse.org
- Failing the test suite is not fatal.
* Wed May 27 2015 dimstar@opensuse.org
- Update to version 0.4.0:
  + Version the builder plugin location.
  + Show a warning when the origin or basename isn't specified.
  + Do not use the cache location when using install-origin with a
    DESTDIR.
  + Release version 0.4.0.
* Mon May 11 2015 dimstar@opensuse.org
- Update to version 0.3.6+git.20150506:
  + trivial: Set the catalog basename as additional metadata.
  + Remove overzealous blacklisting entry.
  + Detect recolorable symbolic icons.
  + Fix exo-web-browser blacklist entry.
  + Add text icons and sample text for some languages.
  + Have another go at fixing font previews.
* Wed Apr 22 2015 dimstar@opensuse.org
- Update to version 0.3.6+git.20150414:
  + trivial: post-branch version bump
  + Use the sanitized font filename as the cache-id
  + trivial: Never attempt to mirror generated screenshots
  + Check for duplicate screenshots when adding fonts
  + trivial: Convert the porting document to markdown
* Fri Apr 10 2015 dimstar@opensuse.org
- Update to version 0.3.6+git.20150409:
  + Fix a crash for an invalid AppData file
* Tue Apr  7 2015 dimstar@opensuse.org
- Move openSUSE-appstream-process definition from
  libzypp-plugin-appdata to appstream-glib: as appstream-glib
  provides the actual code, it's much easier to update the
  openSUSE-appstream-process script in the same package.
* Tue Apr  7 2015 dimstar@opensuse.org
- Update to version 0.3.6+git.20150407:
  + trivial: post release version bump.
  + Build: link libasb_plugin_font.la with GTK3.
  + Allow using as_node_get_localized_unwrap() on unwrapped
    description markup.
  + Remove --extra-appstream from the builder.
  + No longer set PaddedIcon.
  + trivial: Remove some unused code.
  + Add a mirror-screenshots command to appstream-util
  + Remove all networking support when building metadata.
  + Remove the extra screenshots and appdata options from the
    builder.
  + Remove the batch output option from the builder.
  + Do not strip out the source screenshot when using
    mirror-screenshots --nonet.
- Drop appstream-glib-cairo-link.patch: fixed upstream.
* Mon Mar 30 2015 opensuse-packaging@opensuse.org
- Update to version 0.3.6:
  + trivial: post release version bump.
  + trivial: Make the UTF-8 test actually match the comment.
  + Also subsume application licenses.
  + Do not fail due to style warnings when using relaxed
    validation.
  + Add --batch-output to be able to disable the progress panel
    when building.
  + configure.ac: gcab is a hard requirement.
  + Remove the gtk3 dep from libappstream-glib.
  + configure.ac: fix typo.
  + Use the correct image URL for HiDPI screenshots.
  + Allow uninstalling AppStream files from /var/cache.
  + Use the upstream screenshot when we are using appstream-builder
  - -no-net.
  + Make the AppStream builder support optional.
  + Assume the INF DriverVer is UTC.
  + Always upscale screenshots if they are too small.
  + Teach asb_utils_write_archive() how to write other archive
    formats.
  + Put all the screenshots in a file rather than just writing to
    the upload path.
  + If the API version is unspecified when building use the latest
    released version.
  + Add the source-only tags when outputting AppData files.
  + Add a 'replace-screenshots' command to appstream-util.
  + Update the checksums for the gcab-generated firmware.
  + Do not trust the result of FcConfigAppFontAddFile().
  + Release version 0.3.6.
- Drop appstream-glib-uninstall-var-cache.patch: fixed upstream.
- Add appstream-glib-cairo-link.patch: link the font plugin to
  cairo and gtk3.
* Fri Mar 20 2015 dimstar@opensuse.org
- Add appstream-glib-uninstall-var-cache.patch: also remove
  appstream metainfo installed to /var/cache.
- Add
  0001-Add-yast2-branding-openSUSE-if-an-app-depends-on-yas.patch:
  Mark yast2 as a meta-package bringing a set of icons for other
  packages to depend on.
* Tue Mar 17 2015 dimstar@opensuse.org
- Add gdk-pixbuf-loader-rsvg Requires: needed, in order to be able
  to convert .svg icons to pixmaps.
* Fri Mar 13 2015 dimstar@opensuse.org
- Update to version 0.3.5:
  + New Features:
  - Add new API required for firmware support.
  - Add new API required for OSTree and xdg-app support.
  - Add 'news-to-appdata' and 'appdata-to-news' cmds to
    appstream-util.
  - Support all of the yet-unreleased AppStream 0.9 spec.
  + Bugfixes:
  - Add releases from the upstream AppData files.
  - Allow short descriptions when validating <description> in
    releases.
  - Correctly load descriptions from <releases> in AppData files.
  - Fix a builder crash where a package depends on itself.
  - Fix a crash when more than one thread tries to ensure the
    same package.
  - Fix DSO Linking error when built with --as-needed.
  - Make the failed AppStream metadata optional.
  - Make the icon tarball optional.
  - Relax validation checks to allow empty release sections.
  - Return the correct exit code from appstream-builder.
- Add gcab BuildRequires and Requires: needed for the cab
  extraction of the new Firmware support.
* Wed Jan 28 2015 opensuse-packaging@opensuse.org
- Update to version 0.3.4:
  + Allow specifying --packages-dir multiple times
  + Show the offending text when validation fails
  + Do not blacklist applications with broken AppData files
  + Remove the composite plugin
  + Add as_app_get_search_tokens()
  + Add show-search-tokens subcommand to appstream-util
  + Do not store short search tokens like 'a' and 'or'
  + trivial: Do not store search tokens with markup
  + Blacklist the 40 most common search tokens
  + Check if the search entries are valid before searching
  + Accept <metadata_licence> as a fallback for <metadata_license>
  + trivial: Fix 'make distcheck' now the composite plugin has gone
  + Release version 0.3.4
* Mon Jan  5 2015 opensuse-packaging@opensuse.org
- Update to version 0.3.1.git.20150103.a7941d7:
  + Assume that stock icons are available in HiDPI sizes.
  + Blacklist the IBus desktop files used in gnome-control-center.
  + Add several more non-applications to the blacklist.
  + Blacklist KDE3 KCM components.
  + Assume <image>foo</iimagemg> is a source image kind for AppData
    files.
  + trivial: Support ASB_PACKAGE_ENSURE_VCS for RPM packages.
  + Handle other-endian MO files.
  + trivial: Add 4 more stock icons to the whitelist.
  + Fall back to the dumb tokenizer for keywords with special
    chars.
* Wed Dec 24 2014 dimstar@opensuse.org
- Also obsolete appdata-tools-lang to facilitate updates.
* Fri Oct 31 2014 dimstar@opensuse.org
- Update to 0.3.1.git.20141031:
  + Fix make check run in chroot.
  + Merge appdata-validate.
- Enable make check.
- Obsolete and provide appdata-tools by the -devel package:
  appdata-tools has been merged into appstream glib and the
  resulting binary is shipped in our -devel package.
* Thu Oct 30 2014 dimstar@opensuse.org
- Update to 0.3.1.git.20141030.7a5f76a:
  + No longer trip over extracting hardlinked files.
* Thu Oct 23 2014 dimstar@opensuse.org
- Update to version 0.3.1.git.20141023.f8bf1b6:
  + Allow to disable some vetos.
* Wed Oct 22 2014 dimstar@opensuse.org
- Update to version 0.3.1:
  + Add a kudo for a HiDPI ico.
  + Add an --enable-hidpi argument to appstream-builder.
  + New  APIs: AS_APP_VALIDATE_FLAG_ALL_APPS,
    asb_app_set_hidpi_enabled(), asb_context_get_min_icon_size(),
    asb_context_set_embedded_icons(), as_icon_convert_to_kind(),
    as_node_add_attribute_as_int(), as_screenshot_set_priority(),
    as_store_convert_icons(), as_utils_find_icon_filename_full()
    and as_utils_get_string_overlap().
  + Add AsIcon as a new abstract icon object.
  + Add AS_ICON_KIND_EMBEDDED and AS_ICON_KIND_LOCAL.
  + Alpm backend for appstream-builder.
  + Support filtering by metadata in status-csv.
  + Many bugfixes.
- Disable _build_from_cvs, as this is a released tarball again.
* Mon Oct 13 2014 dimstar@opensuse.org
- Update to version 0.3.0.git.20141013.6d59429:
  + Allow to merge icons into appstream xml. Comes in handy for
    OBS, where we generate an appstream with embedded icons.
- Add gobject-introspection-devel BuildRequires: dependency to
  bootstrap the tarball.
- Add conditional (based on _build_from_vcs defines) gnome-common
  BuildRequires and call to autogen.sh: needed, as we are currently
  packaging a git snapshot.
- Add libyaml-devel BuildRequires: new dependency.
- Split new subpackages typelib-1_0-AppstreamBuilder-1_0 and
  typelib-1_0-AppstreamGlib-1_0.
- Rename libappstream-builder1 to libappstream-builder7 and
  libappstream-glib1 to libappstream-glib7, following upstreams
  soname change.
* Wed Oct  8 2014 dimstar@opensuse.org
- Update to version 0.2.6:
  + Add a veto if a .desktop file has NoDisplay=true.
  + Add more things to the blacklist that are not applications.
  + A keyword search match is better than the project name.
  + Turn of sig checking for rpm packages.
  + Update the SPDX license list to v1.20.
- Changes from version 0.2.5:
  + New Features:
  - Add an installed test for the destdir-check.
  - Add as_app_add_veto().
  - Add AS_APP_PARSE_FLAG_ALLOW_VETO.
  - Add AS_STORE_LOAD_FLAG_ALLOW_VETO.
  - Add as_store_remove_all().
  - Add as_store_set_builder_id().
  - Add as_utils_find_icon_filename().
  - Add as_utils_is_spdx_license().
  - Add as_utils_spdx_license_detokenize().
  - Add check-root to appstream-util.
  - Add some validation rules for metainfo files.
  + Bugfixes:
  - Allow desktop->addon demotion with an AppData file.
  - Allow different source roots to define addons.
  - Do not require sentence case when validating with relaxed
    settings.
  - Fix up legacy license IDs when tokenizing.
  - Ignore localized keywords.
  - Ignore localized screenshots.
  - Link client/appstream-util against gdk-pixbuf.
  - Metadata licenses like 'CC0 and CC-BY-3.0' are valid content
    licenses.
  - Never add duplicate <extends> tags.
* Tue Aug 19 2014 dimstar@opensuse.org
- Update to version 0.2.4:
  + New Features:
  - Add AS_PROVIDE_KIND_DBUS_SYSTEM.
  - Add an 'install-origin' command to appstream-util.
  - Add an installed tests to validate appdata.
  - Add as_store_set_destdir() so we can use a different root.
  - Add as_store_validate().
  - Add asb_app_set_veto_description().
  - Add support for <source_pkgname> which will be in
    AppStream 0.8.
  - Add the <dbus> provide for applications automatically.
  + Bugfixes:
  - Add a plugin to detect new-style 'gtk/menus.ui' AppMenu
    support.
  - Avoid using rsync's -a parameter.
  - Detect any addons with missing parents.
  - Do not load applications with NoDisplay=true when loading
    local.
  - Do not pad the compressed AppStream metadata with NUL bytes.
  - Do not treat app-install metadata as installed.
  - Markup errors should not be fatal when assembling a store.
  - Only add registered projects and categories to the metadata.
  - Only link to apps.fedoraproject.org when processing Fedora
    metadata.
  - Show the time remaining when building metadata.
  - Show what application addons extend in status.html.
  - Validate for a sentence case start in <p>, <li> and <name>
    tags.
- Changes from version 0.2.3:
  + New Features:
  - Add some simple filtering in the status.html page.
  - Record if distro metadata and screenshots are being used.
  - Show the builder progress in a ncurses-style panel.
  - Support pre-decompressed RPMs.
  + Bugfixes:
  - Add oxygen-icon-theme when an application depends on
    kde-runtime.
  - Be more careful with untrusted XML data.
  - Do not allow duplicates to be added when using
    as_app_add_kudo_kind().
  - Do not fail to build packages with invalid KDE service files.
  - Do not warn if the AppData file duplicates the .desktop
    value.
  - Show any package duplicates when generating metadata.
  - Show apps with missing icons in the failed metadata.
* Mon Jul 14 2014 dimstar@opensuse.org
- Pass --enable-rpm to configure: we DO want to support RPMs.
- Add pkgconfig(rpm) BuildRequires: required for RPM support.
* Sat Jul 12 2014 dimstar@opensuse.org
- Initial package, version 0.2.2.
